@@ -4,6 +4,14 @@
   register_s3_method("pillar", "pillar_shaft", "yearmonth")
   register_s3_method("pillar", "pillar_shaft", "yearquarter")
 
+  register_s3_method("pillar", "is_vector_s3", "yearweek")
+  register_s3_method("pillar", "is_vector_s3", "yearmonth")
+  register_s3_method("pillar", "is_vector_s3", "yearquarter")
+
+  register_s3_method("pillar", "obj_sum", "yearweek")
+  register_s3_method("pillar", "obj_sum", "yearmonth")
+  register_s3_method("pillar", "obj_sum", "yearquarter")
+
   invisible()
 }
 
