@@ -39,8 +39,8 @@ test_that("a hts", {
   tsbl1 <- as_tsibble(hts::htseg1)
   expect_identical(dim(tsbl1), c(nrow(eg1$bts) * ncol(eg1$bts), 4L))
   expect_identical(
-    format(key(tsbl1)),
-    c("`Level 2` | `Level 1`" = "`Level 2` | `Level 1`")
+    format(key(tsbl1))[[1]],
+    "`Level 2` | `Level 1`"
   )
   expect_identical(unique(tsbl1$`Level 2`), unname(eg1$labels[[3]]))
   expect_identical(tsbl1$`Level 2`, rep(eg1$labels[[3]], each = 10))
